summaryrefslogtreecommitdiffstats
path: root/searchcore
diff options
context:
space:
mode:
authorTor Egge <Tor.Egge@yahoo-inc.com>2017-02-06 10:24:47 +0000
committerTor Egge <Tor.Egge@yahoo-inc.com>2017-02-06 10:24:47 +0000
commit2cc2dce1bfa2be185dc371995139757e4afcd8d8 (patch)
tree4fd635edba084369c05b7df1594269b05c1dfd7f /searchcore
parent1b710c0ca016ed80935693b62e2a00ce7ba0fbd9 (diff)
Prepare for wiring in reference attribute:
- Add data type to attributes.def - Update attribute config conversion - Update attribute factory - Specify that reference attribute doesn't support fast update, docstore must be updated.
Diffstat (limited to 'searchcore')
-rw-r--r--searchcore/src/vespa/searchcore/proton/server/fast_access_feed_view.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/searchcore/src/vespa/searchcore/proton/server/fast_access_feed_view.h b/searchcore/src/vespa/searchcore/proton/server/fast_access_feed_view.h
index 49592f206fb..bdb7a8274ef 100644
--- a/searchcore/src/vespa/searchcore/proton/server/fast_access_feed_view.h
+++ b/searchcore/src/vespa/searchcore/proton/server/fast_access_feed_view.h
@@ -93,9 +93,11 @@ public:
return false;
}
search::attribute::BasicType::Type attrType = attribute->getBasicType();
// Partial update to tensor or predicate attribute must update document
return ((attrType != search::attribute::BasicType::Type::PREDICATE) &&
- (attrType != search::attribute::BasicType::Type::TENSOR));
+ (attrType != search::attribute::BasicType::Type::TENSOR) &&
+ (attrType != search::attribute::BasicType::Type::REFERENCE));
}
};
@@ -93,9 +93,11 @@ public:
}
search::attribute::BasicType::Type attrType = attribute->getBasicType();
- // Partial update to tensor or predicate attribute must update document
+ // Partial update to tensor, predicate or reference attribute
+ // must update document
return ((attrType != search::attribute::BasicType::Type::PREDICATE) &&